/* -*- Mode: C; tab-width: 4 -*-
 *
 * Copyright (c) 2002-2004 Apple Computer, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.

    Change History (most recent first):

$Log: ToolPrefixWindows.h,v $
Revision 1.2  2006/08/14 23:25:59  cheshire
Re-licensed mDNSResponder daemon source code under Apache License, Version 2.0

Revision 1.1  2004/06/18 04:07:54  rpantos
Move up one level

Revision 1.3  2004/01/30 03:04:32  bradley
Updated for latest changes to mDNSWindows.

Revision 1.2  2003/08/20 07:06:34  bradley
Update to APSL 2.0. Updated change history to match other mDNSResponder files.

Revision 1.1  2003/08/20 06:01:19  bradley
Prefix files for CodeWarrior Windows builds to set compile options.
						
*/

#ifndef __TOOL_PREFIX_WINDOWS__
#define __TOOL_PREFIX_WINDOWS__

#define	DEBUG		0

#endif	// __TOOL_PREFIX_WINDOWS__
