; -*- tab-width: 4 -*-
;
; Copyright (c) 2003-2004 Apple Computer, Inc. All rights reserved.
;
; Licensed under the Apache License, Version 2.0 (the "License");
; you may not use this file except in compliance with the License.
; You may obtain a copy of the License at
; 
;     http://www.apache.org/licenses/LICENSE-2.0
; 
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
;
;	Change History (most recent first):
;    
; $Log: dnssd.def,v $
; Revision 1.3  2006/08/14 23:25:41  cheshire
; Re-licensed mDNSResponder daemon source code under Apache License, Version 2.0
;
; Revision 1.2  2004/07/19 07:43:59  shersche
; export TXTRecord APIs
;
; Revision 1.1  2004/06/18 03:55:11  rpantos
; Move DLL up to main level; additional integration from Scott.
;
; Revision 1.2  2004/03/19 10:07:14  bradley
; Export all DNS-SD API symbols from the DLL so they can be used by clients.
;
; Revision 1.1  2004/02/21 04:16:50  bradley
; DLL wrapper for DNS-SD API.
;
;
;

LIBRARY		dnssd

EXPORTS
	DNSServiceRefSockFD
	DNSServiceProcessResult
	DNSServiceRefDeallocate
	DNSServiceEnumerateDomains
	DNSServiceRegister
	DNSServiceAddRecord
	DNSServiceUpdateRecord
	DNSServiceRemoveRecord
	DNSServiceBrowse
	DNSServiceResolve
	DNSServiceConstructFullName
	DNSServiceCreateConnection
	DNSServiceRegisterRecord
	DNSServiceQueryRecord
	DNSServiceReconfirmRecord
	TXTRecordCreate
	TXTRecordDeallocate
	TXTRecordSetValue
	TXTRecordRemoveValue
	TXTRecordContainsKey
	TXTRecordGetCount
	TXTRecordGetLength
	TXTRecordGetBytesPtr
	TXTRecordGetValuePtr
	TXTRecordGetItemAtIndex
