; -*- tab-width: 4 -*-
;
; Copyright (c) 2003-2004 Apple Computer, Inc. All rights reserved.
;
; Licensed under the Apache License, Version 2.0 (the "License");
; you may not use this file except in compliance with the License.
; You may obtain a copy of the License at
; 
;     http://www.apache.org/licenses/LICENSE-2.0
; 
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
;
;	Change History (most recent first):
;    
; $Log: mdnsNSP.def,v $
; Revision 1.4  2006/08/14 23:26:10  cheshire
; Re-licensed mDNSResponder daemon source code under Apache License, Version 2.0
;
; Revision 1.3  2005/01/28 23:48:46  shersche
; <rdar://problem/3942551> Export DllRegisterServer, DllUnregisterServer which can be called from the Installer or regsvr32
; Bug #: 3942551
;
; Revision 1.2  2004/07/13 21:24:28  rpantos
; Fix for <rdar://problem/3701120>.
;
; Revision 1.1  2004/06/18 04:13:44  rpantos
; Move up one level.
;
; Revision 1.1  2004/01/30 03:00:33  bradley
; mDNS NameSpace Provider (NSP). Hooks into the Windows name resolution system to 
; perform .local name lookups using Multicast DNS in all Windows apps.
;
;

LIBRARY		mdnsNSP

EXPORTS
	NSPStartup
	NSPCleanup
	DllRegisterServer	PRIVATE
	DllUnregisterServer	PRIVATE
