/* -*- Mode: C; tab-width: 4 -*-
 *
 * Copyright (c) 2004 Apple Computer, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.

    Change History (most recent first):

$Log: jdns_sd.rc,v $
Revision 1.4  2006/08/14 23:26:04  cheshire
Re-licensed mDNSResponder daemon source code under Apache License, Version 2.0

Revision 1.3  2004/10/19 03:41:42  shersche
<rdar://problem/3843396> Include "afxres.h" to resource script so it gets compiled correctly
Bug #: 3843396

Revision 1.2  2004/06/26 21:27:38  rpantos
Update to use WinVersRes.h

Revision 1.1  2004/06/26 20:06:51  rpantos
Update to use WinVersRes.h


*/

#ifndef JDNS_SD_RC
#define JDNS_SD_RC

#include "afxres.h"
#include "../WinVersRes.h"

/////////////////////////////////////////////////////////////////////////////
//
// Version
//

VS_VERSION_INFO VERSIONINFO
 FILEVERSION MASTER_PROD_VERS
 PRODUCTVERSION MASTER_PROD_VERS
 FILEFLAGSMASK 0x17L
#ifdef _DEBUG
 FILEFLAGS 0x1L
#else
 FILEFLAGS 0x0L
#endif
 FILEOS 0x4L
 FILETYPE 0x2L
 FILESUBTYPE 0x0L
BEGIN
    BLOCK "StringFileInfo"
    BEGIN
        BLOCK "040904b0"
        BEGIN
            VALUE "CompanyName", "Apple Computer, Inc."
            VALUE "FileDescription", MASTER_PROD_NAME " support for Java"
            VALUE "FileVersion", MASTER_PROD_VERS_STR
            VALUE "InternalName", "jdns_sd"
            VALUE "LegalCopyright", "Copyright (C) 2004"
            VALUE "OriginalFilename", "jdns_sd.dll"
            VALUE "ProductName", MASTER_PROD_NAME
            VALUE "ProductVersion", MASTER_PROD_VERS_STR
        END
    END
    BLOCK "VarFileInfo"
    BEGIN
        VALUE "Translation", 0x409, 1200
    END
END

#endif // JDNS_SD_RC
